@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -41,6 +41,7 @@ import java.net.http.HttpHeaders;
 import java.net.http.HttpResponse;
 import jdk.internal.net.http.ResponseContent.BodyParser;
 import jdk.internal.net.http.ResponseContent.UnknownLengthBodyParser;
+import jdk.internal.net.http.ResponseSubscribers.TrustedSubscriber;
 import jdk.internal.net.http.common.Log;
 import jdk.internal.net.http.common.Logger;
 import jdk.internal.net.http.common.MinimalFuture;
@@ -267,6 +268,15 @@ class Http1Response<T> {
         }
     }
 
+    // Used for those response codes that have no body associated
+    public void nullBody(HttpResponse<T> resp, Throwable t) {
+        if (t != null) connection.close();
+        else {
+            return2Cache = !request.isWebSocket();
+            onFinished();
+        }
+    }
+
     static final Flow.Subscription NOP = new Flow.Subscription() {
         @Override
         public void request(long n) { }
@@ -284,7 +294,7 @@ class Http1Response<T> {
      * subscribed.
      * @param <U> The type of response.
      */
-    final static class Http1BodySubscriber<U> implements HttpResponse.BodySubscriber<U> {
+    final static class Http1BodySubscriber<U> implements TrustedSubscriber<U> {
         final HttpResponse.BodySubscriber<U> userSubscriber;
         final AtomicBoolean completed = new AtomicBoolean();
         volatile Throwable withError;
@@ -293,6 +303,11 @@ class Http1Response<T> {
             this.userSubscriber = userSubscriber;
         }
 
+        @Override
+        public boolean needsExecutor() {
+            return TrustedSubscriber.needsExecutor(userSubscriber);
+        }
+
         // propagate the error to the user subscriber, even if not
         // subscribed yet.
         private void propagateError(Throwable t) {
@@ -347,6 +362,7 @@ class Http1Response<T> {
         public CompletionStage<U> getBody() {
             return userSubscriber.getBody();
         }
+
         @Override
         public void onSubscribe(Flow.Subscription subscription) {
             if (!subscribed) {
@@ -466,18 +482,12 @@ class Http1Response<T> {
                 connection.client().unreference();
             }
         });
-        try {
-            p.getBody().whenComplete((U u, Throwable t) -> {
-                if (t == null)
-                    cf.complete(u);
-                else
-                    cf.completeExceptionally(t);
-            });
-        } catch (Throwable t) {
+
+        ResponseSubscribers.getBodyAsync(executor, p, cf, (t) -> {
             cf.completeExceptionally(t);
             asyncReceiver.setRetryOnError(false);
             asyncReceiver.onReadError(t);
-        }
+        });
 
         return cf.whenComplete((s,t) -> {
             if (t != null) {
