@@ -24,8 +24,8 @@
  */
 
 module jdk.internal.vm.compiler {
-    // source file: file:///build/java-openjdk/src/jdk12u-jdk-12.0.2+10/src/jdk.internal.vm.compiler/share/classes/module-info.java
-    //              file:///build/java-openjdk/src/jdk12u-jdk-12.0.2+10/build/linux-x86_64-server-release/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
+    // source file: file:///build/java-openjdk/src/jdk13u-jdk-13.0.1+9/src/jdk.internal.vm.compiler/share/classes/module-info.java
+    //              file:///build/java-openjdk/src/jdk13u-jdk-13.0.1+9/build/linux-x86_64-server-release/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
     requires java.instrument;
     requires java.management;
     requires jdk.internal.vm.ci;
@@ -90,7 +90,8 @@ module jdk.internal.vm.compiler {
     provides jdk.vm.ci.services.JVMCIServiceLocator with org.graalvm.compiler.hotspot.HotSpotGraalJVMCIServiceLocator;
     provides org.graalvm.compiler.code.DisassemblerProvider with
         org.graalvm.compiler.code.HexCodeFileDisassemblerProvider,
-        org.graalvm.compiler.hotspot.meta.HotSpotDisassemblerProvider;
+        org.graalvm.compiler.hotspot.meta.HotSpotDisassemblerProvider,
+        org.graalvm.compiler.hotspot.meta.HotSpotObjdumpDisassemblerProvider;
     provides org.graalvm.compiler.core.match.MatchStatementSet with
         org.graalvm.compiler.core.aarch64.AArch64NodeMatchRules_MatchStatementSet,
         org.graalvm.compiler.core.amd64.AMD64NodeMatchRules_MatchStatementSet,
@@ -105,6 +106,8 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.amd64.AMD64HotSpotBackendFactory,
         org.graalvm.compiler.hotspot.sparc.SPARCHotSpotBackendFactory;
     provides org.graalvm.compiler.nodes.graphbuilderconf.NodeIntrinsicPluginFactory with
+        org.graalvm.compiler.hotspot.amd64.PluginFactory_AMD64X87MathIntrinsicNode,
+        org.graalvm.compiler.hotspot.amd64.PluginFactory_AMD64X87MathSnippets,
         org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_EncodedSymbolNode,
         org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_InitializeKlassStubCall,
         org.graalvm.compiler.hotspot.nodes.aot.PluginFactory_LoadConstantIndirectlyFixedNode,
@@ -133,8 +136,11 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.PluginFactory_AssertionSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CipherBlockChainingSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ClassGetHubNode,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_CounterModeSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CRC32CSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CRC32Substitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_DigestBaseSubstitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotClassSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HotSpotReplacementsUtil,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_HubGetClassNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_IdentityHashCodeNode,
@@ -142,6 +148,8 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.PluginFactory_NewObjectSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA2Substitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA5Substitutions,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_SHASubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ThreadSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_WriteBarrierSnippets,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProbabilisticProfileSnippets,
@@ -154,6 +162,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.debug.PluginFactory_DynamicCounterNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_BranchProbabilityNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_FixedValueAnchorNode,
+        org.graalvm.compiler.nodes.extended.PluginFactory_GuardedUnsafeLoadNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_MembarNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_NullCheckNode,
         org.graalvm.compiler.nodes.extended.PluginFactory_RawLoadNode,
@@ -169,6 +178,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.memory.PluginFactory_MemoryAnchorNode,
         org.graalvm.compiler.nodes.PluginFactory_BreakpointNode,
         org.graalvm.compiler.nodes.PluginFactory_ComputeObjectAddressNode,
+        org.graalvm.compiler.nodes.PluginFactory_ConstantNode,
         org.graalvm.compiler.nodes.PluginFactory_DeoptimizeNode,
         org.graalvm.compiler.nodes.PluginFactory_GetObjectAddressNode,
         org.graalvm.compiler.nodes.PluginFactory_PauseNode,
@@ -180,15 +190,13 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64IntegerArithmeticSnippets,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOfNode,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOf,
-        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64MathSubstitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1InflateNode,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1Substitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringSubstitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringUTF16CompressNode,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringUTF16Substitutions,
         org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyCallNode,
-        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopySnippets,
-        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyWithSlowPathNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyWithDelayedLoweringNode,
         org.graalvm.compiler.replacements.arraycopy.PluginFactory_CheckcastArrayCopyCallNode,
         org.graalvm.compiler.replacements.arraycopy.PluginFactory_GenericArrayCopyCallNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayCompareToNode,
@@ -202,6 +210,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.nodes.PluginFactory_DirectStoreNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ExplodeLoopNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_UnaryMathIntrinsicNode,
+        org.graalvm.compiler.replacements.nodes.PluginFactory_ZeroMemoryNode,
         org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
         org.graalvm.compiler.replacements.PluginFactory_Log,
         org.graalvm.compiler.replacements.PluginFactory_ReplacementsUtil,
