@@ -144,7 +144,7 @@ public class FormatData extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
             };
@@ -160,22 +160,31 @@ public class FormatData extends ListResourceBundle {
                "GGGG y MMM d",
                "G y-MM-dd",
             };
-        final String[] metaValue_japanese_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
                "CE",
                "Meiji",
                "Taish\u014d",
                "Sh\u014dwa",
                "Heisei",
+               "Reiwa",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_narrow_Eras = new String[] {
+               "CE",
+               "M",
+               "T",
+               "S",
+               "H",
+               "R",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "Before R.O.C.",
                "R.O.C.",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "AH",
             };
-        final String[] metaValue_brah_NumberElements = new String[] {
+        final String[] metaValue_adlm_NumberElements = new String[] {
                ".",
                ",",
                ";",
@@ -188,10 +197,29 @@ public class FormatData extends ListResourceBundle {
                "\u221e",
                "NaN",
             };
+        final String[] metaValue_short_CompactNumberPatterns = new String[] {
+               "",
+               "",
+               "",
+               "0K",
+               "00K",
+               "000K",
+               "0M",
+               "00M",
+               "000M",
+               "0G",
+               "00G",
+               "000G",
+               "0T",
+               "00T",
+               "000T",
+            };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "mroo.NumberElements", metaValue_brah_NumberElements },
+            { "java.time.japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
+            { "mroo.NumberElements", metaValue_adlm_NumberElements },
             { "field.year", "Year" },
+            { "rohg.NumberElements", metaValue_adlm_NumberElements },
             { "arabext.NumberElements",
                 new String[] {
                     "\u066b",
@@ -208,7 +236,7 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "GMT{0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -228,17 +256,9 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "japanese.narrow.Eras",
-                new String[] {
-                    "CE",
-                    "M",
-                    "T",
-                    "S",
-                    "H",
-                }
-            },
+            { "japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "hmng.NumberElements", metaValue_brah_NumberElements },
+            { "hmng.NumberElements", metaValue_adlm_NumberElements },
             { "mymr.NumberElements",
                 new String[] {
                     ".",
@@ -256,8 +276,8 @@ public class FormatData extends ListResourceBundle {
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_long_Eras },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
-            { "mathdbl.NumberElements", metaValue_brah_NumberElements },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "mathdbl.NumberElements", metaValue_adlm_NumberElements },
             { "talu.NumberElements",
                 new String[] {
                     ".",
@@ -292,7 +312,7 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "sind.NumberElements", metaValue_brah_NumberElements },
+            { "sind.NumberElements", metaValue_adlm_NumberElements },
             { "mtei.NumberElements",
                 new String[] {
                     ".",
@@ -310,9 +330,10 @@ public class FormatData extends ListResourceBundle {
             },
             { "timezone.gmtZeroFormat", "GMT" },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "mathmono.NumberElements", metaValue_brah_NumberElements },
+            { "mathmono.NumberElements", metaValue_adlm_NumberElements },
             { "standalone.DayAbbreviations", metaValue_DayNames },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "beng.NumberElements",
                 new String[] {
                     ".",
@@ -357,7 +378,8 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "latn.NumberElements", metaValue_brah_NumberElements },
+            { "gong.NumberElements", metaValue_adlm_NumberElements },
+            { "latn.NumberElements", metaValue_adlm_NumberElements },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "guru.NumberElements",
@@ -377,10 +399,10 @@ public class FormatData extends ListResourceBundle {
             },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "Minute" },
-            { "japanese.long.Eras", metaValue_japanese_long_Eras },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "Era" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "mathsanb.NumberElements", metaValue_brah_NumberElements },
+            { "mathsanb.NumberElements", metaValue_adlm_NumberElements },
             { "field.dayperiod", "Dayperiod" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "cham.NumberElements",
@@ -398,8 +420,8 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "mathsans.NumberElements", metaValue_brah_NumberElements },
-            { "ahom.NumberElements", metaValue_brah_NumberElements },
+            { "mathsans.NumberElements", metaValue_adlm_NumberElements },
+            { "ahom.NumberElements", metaValue_adlm_NumberElements },
             { "islamic.MonthNames",
                 new String[] {
                     "Muharram",
@@ -433,6 +455,7 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "wcho.NumberElements", metaValue_adlm_NumberElements },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -448,8 +471,8 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "shrd.NumberElements", metaValue_brah_NumberElements },
-            { "takr.NumberElements", metaValue_brah_NumberElements },
+            { "shrd.NumberElements", metaValue_adlm_NumberElements },
+            { "takr.NumberElements", metaValue_adlm_NumberElements },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "deva.NumberElements",
                 new String[] {
@@ -466,10 +489,11 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "Month" },
-            { "osma.NumberElements", metaValue_brah_NumberElements },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "osma.NumberElements", metaValue_adlm_NumberElements },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "Second" },
             { "islamic.MonthNarrows",
                 new String[] {
@@ -498,7 +522,8 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "gonm.NumberElements", metaValue_brah_NumberElements },
+            { "gonm.NumberElements", metaValue_adlm_NumberElements },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "knda.NumberElements",
                 new String[] {
                     ".",
@@ -529,13 +554,15 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "brah.NumberElements", metaValue_brah_NumberElements },
+            { "brah.NumberElements", metaValue_adlm_NumberElements },
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
+            { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "timezone.regionFormat", "{0}" },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "modi.NumberElements", metaValue_brah_NumberElements },
+            { "modi.NumberElements", metaValue_adlm_NumberElements },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "olck.NumberElements",
                 new String[] {
@@ -554,6 +581,7 @@ public class FormatData extends ListResourceBundle {
             },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "mymrshan.NumberElements",
                 new String[] {
                     ".",
@@ -569,7 +597,7 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "DateTimePatternChars", "GyMdkHmsSEDFwWahKzZ" },
             { "mlym.NumberElements",
                 new String[] {
@@ -633,6 +661,7 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "khmr.NumberElements",
                 new String[] {
                     ".",
@@ -649,7 +678,7 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "field.zone", "Zone" },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "laoo.NumberElements",
                 new String[] {
                     ".",
@@ -714,7 +743,7 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "roc.DayNames", metaValue_DayNames },
-            { "bhks.NumberElements", metaValue_brah_NumberElements },
+            { "bhks.NumberElements", metaValue_adlm_NumberElements },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -735,13 +764,15 @@ public class FormatData extends ListResourceBundle {
             },
             { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "newa.NumberElements", metaValue_brah_NumberElements },
+            { "newa.NumberElements", metaValue_adlm_NumberElements },
             { "field.weekday", "Day of the Week" },
-            { "tirh.NumberElements", metaValue_brah_NumberElements },
+            { "tirh.NumberElements", metaValue_adlm_NumberElements },
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "islamic.DayAbbreviations", metaValue_DayNames },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "telu.NumberElements",
                 new String[] {
                     ".",
@@ -757,6 +788,7 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "hmnp.NumberElements", metaValue_adlm_NumberElements },
             { "timezone.hourFormat", "+HH:mm;-HH:mm" },
             { "nkoo.NumberElements",
                 new String[] {
@@ -773,7 +805,7 @@ public class FormatData extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "cakm.NumberElements", metaValue_brah_NumberElements },
+            { "cakm.NumberElements", metaValue_adlm_NumberElements },
             { "tibt.NumberElements",
                 new String[] {
                     ".",
@@ -791,7 +823,7 @@ public class FormatData extends ListResourceBundle {
             },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayNames },
-            { "wara.NumberElements", metaValue_brah_NumberElements },
+            { "wara.NumberElements", metaValue_adlm_NumberElements },
             { "DayNames", metaValue_DayNames },
             { "lanatham.NumberElements",
                 new String[] {
@@ -809,10 +841,11 @@ public class FormatData extends ListResourceBundle {
                 }
             },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "sora.NumberElements", metaValue_brah_NumberElements },
-            { "mathbold.NumberElements", metaValue_brah_NumberElements },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "sora.NumberElements", metaValue_adlm_NumberElements },
+            { "mathbold.NumberElements", metaValue_adlm_NumberElements },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "Week" },
             { "gujr.NumberElements",
                 new String[] {
@@ -881,6 +914,8 @@ public class FormatData extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} (+1)" },
             { "DatePatterns",
                 new String[] {
@@ -927,15 +962,16 @@ public class FormatData extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "adlm.NumberElements", metaValue_brah_NumberElements },
+            { "adlm.NumberElements", metaValue_adlm_NumberElements },
             { "QuarterAbbreviations", metaValue_QuarterNames },
-            { "japanese.Eras", metaValue_japanese_long_Eras },
+            { "japanese.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
         return data;
