@@ -172,13 +172,7 @@ public class FormatData_nb extends ListResourceBundle {
                "f.Kr.",
                "e.Kr.",
             };
-        final String[] metaValue_TimePatterns = new String[] {
-               "HH:mm:ss zzzz",
-               "HH:mm:ss z",
-               "HH:mm:ss",
-               "HH:mm",
-            };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
             };
@@ -194,13 +188,35 @@ public class FormatData_nb extends ListResourceBundle {
                "d. MMM y GGGG",
                "d.M.y GGGG",
             };
-        final String[] metaValue_buddhist_DateTimePatterns = new String[] {
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "etter Kristus",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "Heisei",
+               "Reiwa",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "e.Kr.",
+               "Meiji",
+               "Taish\u014d",
+               "Sh\u014dwa",
+               "Heisei",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "F\u00f8r R.O.C.",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
+               "F\u00f8r ROC",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_roc_narrow_Eras = new String[] {
+               "",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "AH",
             };
@@ -238,7 +254,7 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -265,16 +281,6 @@ public class FormatData_nb extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "japanese.narrow.Eras",
-                new String[] {
-                    "e.Kr.",
-                    "M",
-                    "T",
-                    "S",
-                    "H",
-                    "",
-                }
-            },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "islamsk kalender (tabell, sivil)" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -293,14 +299,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras",
-                new String[] {
-                    "F\u00f8r R.O.C.",
-                    "Minguo",
-                }
-            },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "talu.NumberElements",
                 new String[] {
                     ",",
@@ -353,6 +353,7 @@ public class FormatData_nb extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "beng.NumberElements",
                 new String[] {
                     ",",
@@ -429,17 +430,8 @@ public class FormatData_nb extends ListResourceBundle {
             },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minutt" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "tidsalder" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "etter Kristus",
-                    "Meiji",
-                    "Taish\u014d",
-                    "Sh\u014dwa",
-                    "Heisei",
-                    "",
-                }
-            },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "a.m./p.m." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
@@ -511,16 +503,12 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "m\u00e5ned" },
             { "osma.NumberElements", metaValue_brah_NumberElements },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "sekund" },
-            { "roc.Eras",
-                new String[] {
-                    "F\u00f8r ROC",
-                    "Minguo",
-                }
-            },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
             { "NumberPatterns",
@@ -532,6 +520,7 @@ public class FormatData_nb extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamsk kalender" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "knda.NumberElements",
                 new String[] {
                     ",",
@@ -562,8 +551,8 @@ public class FormatData_nb extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
             { "standalone.MonthAbbreviations",
                 new String[] {
@@ -624,6 +613,7 @@ public class FormatData_nb extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "mymrshan.NumberElements",
                 new String[] {
                     ",",
@@ -640,7 +630,7 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "mlym.NumberElements",
                 new String[] {
                     ",",
@@ -671,7 +661,6 @@ public class FormatData_nb extends ListResourceBundle {
                     "NaN",
                 }
             },
-            { "TimePatterns", metaValue_TimePatterns },
             { "lepc.NumberElements",
                 new String[] {
                     ",",
@@ -703,6 +692,7 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "khmr.NumberElements",
                 new String[] {
                     ",",
@@ -720,13 +710,7 @@ public class FormatData_nb extends ListResourceBundle {
             },
             { "field.zone", "tidssone" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
-            { "roc.narrow.Eras",
-                new String[] {
-                    "",
-                    "Minguo",
-                }
-            },
+            { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
             { "laoo.NumberElements",
                 new String[] {
                     ",",
@@ -812,12 +796,13 @@ public class FormatData_nb extends ListResourceBundle {
             { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "ukedag" },
-            { "islamic.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "telu.NumberElements",
                 new String[] {
                     ",",
@@ -883,11 +868,11 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
             { "sora.NumberElements", metaValue_brah_NumberElements },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "uke" },
-            { "buddhist.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
             { "gujr.NumberElements",
                 new String[] {
                     ",",
@@ -948,18 +933,19 @@ public class FormatData_nb extends ListResourceBundle {
                     "0k",
                     "00k",
                     "000k",
-                    "0\u00a0mill",
-                    "00\u00a0mill",
-                    "000\u00a0mill",
-                    "0\u00a0mrd",
-                    "00\u00a0mrd",
-                    "000\u00a0mrd",
-                    "0\u00a0bill",
-                    "00\u00a0bill",
-                    "000\u00a0bill",
+                    "0\u00a0mill'.'",
+                    "00\u00a0mill'.'",
+                    "000\u00a0mill'.'",
+                    "0\u00a0mrd'.'",
+                    "00\u00a0mrd'.'",
+                    "000\u00a0mrd'.'",
+                    "0\u00a0bill'.'",
+                    "00\u00a0bill'.'",
+                    "000\u00a0bill'.'",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "sommertid \u2013 {0}" },
             { "DatePatterns",
                 new String[] {
@@ -970,8 +956,6 @@ public class FormatData_nb extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "japanese.DateTimePatterns", metaValue_buddhist_DateTimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "time" },
@@ -1007,24 +991,15 @@ public class FormatData_nb extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "buddhistisk kalender" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
-            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "e.Kr.",
-                    "Meiji",
-                    "Taish\u014d",
-                    "Sh\u014dwa",
-                    "Heisei",
-                    "",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
